@@ -25,7 +25,7 @@
 struct markdata
 {
   struct win *md_window;/* pointer to window we are working on */
-  struct user *md_user;	/* The user who brought us up */
+  struct acluser *md_user;	/* The user who brought us up */
   int	cx, cy;		/* cursor Position in WIN coords*/
   int	x1, y1;		/* first mark in WIN coords */
   int	second;		/* first mark dropped flag */
